@@ -1,7 +1,4 @@
-
-"""
-
-__init__.py
+"""yolk
 
 Author: Rob Cakebread <cakebread at gmail>
 
@@ -9,5 +6,4 @@ License  : BSD
 
 """
 
-__docformat__ = 'restructuredtext'
-__version__ = '0.5.1'
+__version__ = '0.5.2'
