@@ -1,10 +1,7 @@
 # pylint: disable-msg=W0613,W0612,W0212,W0511,R0912,C0322,W0704
 # W0511 = XXX (my own todo's)
 
-"""
-
-cli.py
-======
+"""cli
 
 Desc: Command-line tool for listing Python packages installed by setuptools,
       package metadata, package dependencies, and querying The Cheese Shop
@@ -47,9 +44,6 @@ from yolk.utils import run_command, command_successful
 from yolk.__init__ import __version__ as VERSION
 
 
-__docformat__ = 'restructuredtext'
-
-
 class StdOut:
 
     """Filter stdout or stderr from specific modules So far this is just used
@@ -846,7 +840,7 @@ class Yolk(object):
                 print('   %s' % entry_point)
                 if plugin.__doc__:
                     print(plugin.__doc__)
-                print
+                print()
             except ImportError:
                 pass
         if not found:
