@@ -1,10 +1,7 @@
 # pylint: disable-msg=W0212
 # W0212 Access to a protected member _headers of a client class
 
-"""
-
-metadata.py
-===========
+"""metadata
 
 Author   : Rob Cakebread <cakebread @ gmail>
 
@@ -17,8 +14,6 @@ Desc     : Return metadata for Python distribution installed by setuptools
 
 """
 
-__docformat__ = 'restructuredtext'
-
 import email
 
 
