@@ -1,8 +1,4 @@
-
-"""
-
-pypi.py
-=======
+"""pypi
 
 Desc: Library for getting information about Python packages by querying
       The CheeseShop (PYPI a.k.a. Python Package Index).
@@ -14,8 +10,6 @@ License  : BSD (See COPYING)
 
 """
 
-__docformat__ = 'restructuredtext'
-
 import re
 import platform
 if platform.python_version().startswith('2'):
@@ -33,7 +27,7 @@ import logging
 from yolk.utils import get_yolk_dir
 
 
-XML_RPC_SERVER = 'http://pypi.python.org/pypi'
+XML_RPC_SERVER = 'https://pypi.python.org/pypi'
 
 
 class ProxyTransport(xmlrpclib.Transport):
@@ -72,9 +66,13 @@ class ProxyTransport(xmlrpclib.Transport):
 
 def check_proxy_setting():
     """If the environmental variable 'HTTP_PROXY' is set, it will most likely
-    be in one of these forms: proxyhost:8080 http://proxyhost:8080 urlllib2
+    be in one of these forms:
+
+    proxyhost:8080 http://proxyhost:8080 urlllib2
     requires the proxy URL to start with 'http://' This routine does that, and
-    returns the transport for xmlrpc."""
+    returns the transport for xmlrpc.
+
+    """
     try:
         http_proxy = os.environ['HTTP_PROXY']
     except KeyError:
@@ -115,9 +113,9 @@ class CheeseShop(object):
 
         if not os.path.exists(self.yolk_dir):
             os.mkdir(self.yolk_dir)
-        if os.path.exists(self.pkg_cache_file):
+        try:
             self.pkg_list = self.query_cached_package_list()
-        else:
+        except (IOError, ValueError):
             self.logger.debug(
                 'DEBUG: Fetching package list cache from PyPi...')
             self.fetch_pkg_list()
