@@ -1,17 +1,11 @@
-
-
-"""
-
-utils.py
-===========
+"""utils
 
 Misc funcitions
 ---------------
 
 run_command borrowed from Cheesecake - See CREDITS.
-"""
 
-__docformat__ = 'restructuredtext'
+"""
 
 import os
 import signal
